ShapeMorphSlot<T> class

ShapeMorphSlot - Morph between different shapes.

Animates between geometric shapes like circles, rectangles, and rounded rects.

Example:

ShapeMorphSlot<bool>(
  connect: controller.isExpanded,
  shapeBuilder: (expanded) => expanded
      ? ShapeConfig.roundedRect(borderRadius: 16)
      : ShapeConfig.circle(),
  size: (expanded) => expanded ? Size(200, 300) : Size(60, 60),
  color: (expanded) => expanded ? Colors.blue : Colors.green,
  child: (expanded) => expanded
      ? ExpandedContent()
      : Icon(Icons.add),
)
Inheritance
Available extensions

Constructors

ShapeMorphSlot({Key? key, required Signal<T> connect, required ShapeConfig shapeBuilder(T value), required Size sizeBuilder(T value), required Widget childBuilder(T value), Color colorBuilder(T value)?, List<BoxShadow> shadowBuilder(T value)?, Duration duration = const Duration(milliseconds: 400), Curve curve = Curves.easeInOutCubic})
const

Properties

childBuilder Widget Function(T value)
final
colorBuilder Color Function(T value)?
final
connect Signal<T>
final
curve Curve
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowBuilder List<BoxShadow> Function(T value)?
final
shapeBuilder ShapeConfig Function(T value)
final
sizeBuilder Size Function(T value)
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(VoidCallback onTap, {double pressedScale = 0.95}) Widget

Available on Widget, provided by the SlotWidgetModifiers extension

Wrap with tap gesture.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withDelay(Duration delay) Widget

Available on Widget, provided by the SlotWidgetModifiers extension

Add a delay before showing.
withFade({Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Widget

Available on Widget, provided by the SlotWidgetModifiers extension

Wrap with fade animation on appear.
withHero(Object tag) Widget

Available on Widget, provided by the SlotWidgetModifiers extension

Wrap with hero animation.
withScale({double begin = 0.8, double end = 1.0, Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeOutBack}) Widget

Available on Widget, provided by the SlotWidgetModifiers extension

Wrap with scale animation on appear.
withShimmer({Duration duration = const Duration(milliseconds: 1500), Color baseColor = const Color(0xFFE0E0E0), Color highlightColor = const Color(0xFFF5F5F5)}) Widget

Available on Widget, provided by the SlotWidgetModifiers extension

Apply a shimmer loading effect.
withSlide({Offset begin = const Offset(0, 0.2), Offset end = Offset.zero, Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeOutCubic}) Widget

Available on Widget, provided by the SlotWidgetModifiers extension

Wrap with slide animation on appear.

Operators

operator ==(Object other) bool
The equality operator.
inherited